@@ -35,7 +35,7 @@ def test_apply_historical_return(ohlc_prices):
     # arrange
     periods = [3, 4]
     magnifier_multiplier = 2
-    expected_operators = [HistoricalReturnOperator.__name__]
+    expected_operators = [ReturnsOperator.__name__]
     original_ohlc = ohlc_prices.copy()
 
     # act
